==> kdepim-addons-18.11.80.tar.xz: kdepim-addons-18.11.80/kmail/editorplugins/changecase/changecaseplugineditor.cpp <==
/*
   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "changecaseplugineditor.h"
#include "changecaseplugineditorinterface.h"
#include <kpluginfactory.h>

K_PLUGIN_CLASS_WITH_JSON(ChangeCasePluginEditor, "kmail_changecaseeditorplugin.json")

ChangeCasePluginEditor::ChangeCasePluginEditor(QObject *parent, const QList<QVariant> &)
    : MessageComposer::PluginEditor(parent)
{
}

ChangeCasePluginEditor::~ChangeCasePluginEditor()
{
}

bool ChangeCasePluginEditor::hasPopupMenuSupport() const
{
    return true;
}

MessageComposer::PluginEditorInterface *ChangeCasePluginEditor::createInterface(KActionCollection *ac, QObject *parent)
{
    ChangeCasePluginEditorInterface *interface = new ChangeCasePluginEditorInterface(parent);
    interface->createAction(ac);
    return interface;
}

#include "changecaseplugineditor.moc"

==> kdepim-addons-18.12.2.tar.xz: kdepim-addons-18.12.2/kmail/editorplugins/changecase/changecaseplugineditor.cpp <==
/*
   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "changecaseplugineditor.h"
#include "changecaseplugineditorinterface.h"
#include <kpluginfactory.h>

K_PLUGIN_CLASS_WITH_JSON(ChangeCasePluginEditor, "kmail_changecaseeditorplugin.json")

ChangeCasePluginEditor::ChangeCasePluginEditor(QObject *parent, const QList<QVariant> &)
    : MessageComposer::PluginEditor(parent)
{
}

ChangeCasePluginEditor::~ChangeCasePluginEditor()
{
}

bool ChangeCasePluginEditor::hasPopupMenuSupport() const
{
    return true;
}

MessageComposer::PluginEditorInterface *ChangeCasePluginEditor::createInterface(QObject *parent)
{
    ChangeCasePluginEditorInterface *interface = new ChangeCasePluginEditorInterface(parent);
    return interface;
}

#include "changecaseplugineditor.moc"
